==> APMServices-SDK-iOS-1.5.3.tar.gz: APMServices-SDK-iOS-1.5.3/APMServices/Frameworks/APMServices.framework/Versions/A/Headers/APMServicesConfig.h <==
//
//  APMServicesConfig.h
//  APMServices
//
//  Created by Vincent Ducastel on 01/10/2014.
//  Copyright (c) 2015 Moonmiles. All rights reserved.
//

// Version of API
#define APM_API_VERSION @"2.0"
#define APM_SERVICES_VERSION_NAME @"1.5.3"
#define APM_SERVICES_VERSION_CODE @"158"

//URL
#define APM_URL_API_PROD @"https://api.appsmiles.eu/" //Url API prod
#define APM_URL_API_SANDBOX @"https://api-sandbox.appsmiles.eu/" //Url API sandbox
#define APM_URL_SITE_APPSMILES @"http://www.appsmiles.eu" //Url du site web

//Partner Level
#define APM_PARTNER_LEVEL_INITIAL  1
#define APM_PARTNER_LEVEL_STANDARD 2
#define APM_PARTNER_LEVEL_PREMIUM  3

//Gender
#define APM_K_USER_GENDER_MME        1
#define APM_K_USER_GENDER_M          2

//Type gift
#define APM_GIFT_TYPE_TEXT         1
#define APM_GIFT_TYPE_BARCODE      2
#define APM_GIFT_TYPE_OBJECT       3
#define APM_GIFT_TYPE_URL          4
#define APM_GIFT_TYPE_EMAIL        5

//Nature gift
#define APM_GIFT_NATURE_POINTS      1
#define APM_GIFT_NATURE_STATUS      2

//Page
#define APM_SHOW_PAGE_CNIL             1
#define APM_SHOW_PAGE_CGU              2
#define APM_SHOW_PAGE_MENTIONS         3
#define APM_SHOW_PAGE_HELPER           4
#define APM_SHOW_PAGE_TUTO             5
#define APM_SHOW_PAGE_INTERSTITIAL     6
#define APM_SHOW_PAGE_APP_ONBOARDING   7
#define APM_SHOW_PAGE_APP_MENTION      8
#define APM_SHOW_PAGE_APP_TUTORIAL     9
#define APM_SHOW_PAGE_APP_INTERSTITIAL 10

//Type howworks
#define APM_HOW_WORKS_TYPE_WEBVIEW 1
#define APM_HOW_WORKS_TYPE_ACTIONS 2
#define APM_HOW_WORKS_TYPE_GIFTS   3

//HowWorks target
#define APM_HOWWORKS_TARGET_ONLY_NOT_CONNECTED 0
#define APM_HOWWORKS_TARGET_ONLY_CONNECTED 1
#define APM_HOWWORKS_TARGET_BOTH 2

//Walkthrough target
#define APM_WALKTHROUGH_TARGET_ONLY_NOT_CONNECTED 0
#define APM_WALKTHROUGH_TARGET_ONLY_CONNECTED 1
#define APM_WALKTHROUGH_TARGET_BOTH 2

//Walkthrough status
#define APM_WALKTHROUGH_STATUS_OFFLINE 0
#define APM_WALKTHROUGH_STATUS_ONLINE 1

// Exceptions
#define APM_EXCEPTION_NO_ERROR        0

// Exceptions server
#define APM_EXCEPTION_ERROR_SERVER    1
#define APM_EXCEPTION_INVALID_TOKEN   2
#define APM_EXCEPTION_MODE_TEST       5

// Exceptions mobiles
#define APM_EXCEPTION_NO_NETWORK              -100
#define APM_EXCEPTION_UNKNOWN_ERROR           -101
#define APM_EXCEPTION_SERVICE_LOADING         -102
#define APM_EXCEPTION_SERVICE_NOT_ACTIVE      -103
#define APM_EXCEPTION_CONFIG                  -105
#define APM_EXCEPTION_ACCOUNT_NOT_CONNECTED   -106
#define APM_EXCEPTION_HTTP_REQUEST_ERROR      -107
#define APM_EXCEPTION_URL_HTTP_INVALID        -108

//Format Date
#define APM_DEFAULT_DATE_FORMAT @"dd/MM/yyyy"

//Device status
#define APM_DEVICE_STATUS_NOT_SET -1
#define APM_DEVICE_STATUS_OK 0
#define APM_DEVICE_STATUS_ANONYMOUS 1
#define APM_DEVICE_STATUS_OPTIN_OFF 2

//Class id
#define APM_CLASS_ID_GLOBAL @"global"

//Class id
#define APM_AD_TYPE_CUMUL   @"1"
#define APM_AD_TYPE_BONUS   @"2"

//Generosity type
#define APM_GENEROSITY_TYPE_SYSTEMATIC 1
#define APM_GENEROSITY_TYPE_SUGGESTED 2

==> APMServices-SDK-iOS-2.1.9.tar.gz: APMServices-SDK-iOS-2.1.9/APMServices/Frameworks/APMServices.framework/Versions/A/Headers/APMServicesConfig.h <==
//
//  APMServicesConfig.h
//  APMServices
//
//  Created by Vincent Ducastel on 01/10/2014.
//  Copyright (c) 2015 Moonmiles. All rights reserved.
//

// Version of API
#define APM_API_VERSION @"3.0"
#define APM_SERVICES_VERSION_NAME @"2.1.9"
#define APM_SERVICES_VERSION_CODE @"2190"

//URL
#define APM_URL_API_PROD @"https://api.appsmiles.eu/" //Url API prod
#define APM_URL_API_SANDBOX @"https://api-sandbox.appsmiles.eu/" //Url API sandbox
#define APM_URL_SITE_APPSMILES @"http://www.appsmiles.eu" //Url du site web

//Partner Level
#define APM_PARTNER_LEVEL_INITIAL  1
#define APM_PARTNER_LEVEL_STANDARD 2
#define APM_PARTNER_LEVEL_PREMIUM  3

//Gender
#define APM_K_USER_GENDER_MME        1
#define APM_K_USER_GENDER_M          2

//Type gift
#define APM_GIFT_TYPE_TEXT         1
#define APM_GIFT_TYPE_BARCODE      2
#define APM_GIFT_TYPE_OBJECT       3
#define APM_GIFT_TYPE_URL          4
#define APM_GIFT_TYPE_EMAIL        5

//Nature gift
#define APM_GIFT_NATURE_POINTS      1
#define APM_GIFT_NATURE_STATUS      2

//Status burn
#define APM_BURN_STATUS_UNDEFINED   -1
#define APM_BURN_STATUS_ISSUED       0
#define APM_BURN_STATUS_USED         1
#define APM_BURN_STATUS_CANCELED     2
#define APM_BURN_STATUS_EXPIRED      3

//Page
#define APM_SHOW_PAGE_CNIL             1
#define APM_SHOW_PAGE_CGU              2
#define APM_SHOW_PAGE_MENTIONS         3
#define APM_SHOW_PAGE_HELPER           4
#define APM_SHOW_PAGE_TUTO             5
#define APM_SHOW_PAGE_INTERSTITIAL     6
#define APM_SHOW_PAGE_APP_ONBOARDING   7
#define APM_SHOW_PAGE_APP_MENTION      8
#define APM_SHOW_PAGE_APP_TUTORIAL     9
#define APM_SHOW_PAGE_APP_INTERSTITIAL 10

//Type howworks
#define APM_HOW_WORKS_TYPE_WEBVIEW 1
#define APM_HOW_WORKS_TYPE_ACTIONS 2
#define APM_HOW_WORKS_TYPE_GIFTS   3

//Page target
#define APM_PAGE_TARGET_ONLY_NOT_CONNECTED 0
#define APM_PAGE_TARGET_ONLY_CONNECTED 1
#define APM_PAGE_TARGET_BOTH 2

//Walkthrough status
#define APM_WALKTHROUGH_STATUS_OFFLINE 0
#define APM_WALKTHROUGH_STATUS_ONLINE 1

// Exceptions
#define APM_EXCEPTION_NO_ERROR        0

// Exceptions server
#define APM_EXCEPTION_ERROR_SERVER    1
#define APM_EXCEPTION_INVALID_TOKEN   2
#define APM_EXCEPTION_MODE_TEST       5
#define APM_EXCEPTION_ERROR_500       500 //Internal error
#define APM_EXCEPTION_ERROR_404       404 //Not found
#define APM_EXCEPTION_ERROR_401       401 //Signature error

// Exceptions mobiles
#define APM_EXCEPTION_NO_NETWORK              -100
#define APM_EXCEPTION_UNKNOWN_ERROR           -101
#define APM_EXCEPTION_SERVICE_LOADING         -102
#define APM_EXCEPTION_SERVICE_NOT_ACTIVE      -103
#define APM_EXCEPTION_CONFIG                  -105
#define APM_EXCEPTION_ACCOUNT_NOT_CONNECTED   -106
#define APM_EXCEPTION_URL_HTTP_INVALID        -108
#define APM_EXCEPTION_OPT_IN_NOT_ACCEPTED     -109
#define APM_EXCEPTION_ACTION_NOT_FOUND        -110

//Format Date
#define APM_DEFAULT_DATE_FORMAT @"dd/MM/yyyy"

//Device status
#define APM_DEVICE_STATUS_NOT_SET -1
#define APM_DEVICE_STATUS_OK 0
#define APM_DEVICE_STATUS_ANONYMOUS 1
#define APM_DEVICE_STATUS_OPTIN_OFF 2

//Opt-In
#define APM_DEVICE_OPT_IN_NOT_SET -1
#define APM_DEVICE_OPT_IN_REFUSE 1
#define APM_DEVICE_OPT_IN_ACCEPT 0

//Class id
#define APM_CLASS_ID_GLOBAL @"global"

//Ads
#define APM_AD_TYPE_BONUS      3
#define APM_AD_TYPE_NEWS       4
#define APM_AD_TYPE_SPECIALS   5

//Generosity type
#define APM_GENEROSITY_TYPE_SYSTEMATIC 1
#define APM_GENEROSITY_TYPE_SUGGESTED 2
#define APM_GENEROSITY_TYPE_AUTOMATIC 3

//TriggerAction Cache Policy
#define APM_TRIGGER_CACHE_POLICY_DISCARD -1
#define APM_TRIGGER_CACHE_POLICY_STORE_ALWAYS 0

//Product availability
#define APM_PRODUCT_AVAILABILITY_UNAVAILABLE 0
#define APM_PRODUCT_AVAILABILITY_AVAILABLE 1
